===============================
romannumeral
===============================

.. image:: https://badge.fury.io/py/romannumeral.png
    :target: http://badge.fury.io/py/romannumeral

.. image:: https://travis-ci.org/jay3686/romannumeral.png?branch=master
        :target: https://travis-ci.org/jay3686/romannumeral

.. image:: https://pypip.in/d/romannumeral/badge.png
        :target: https://pypi.python.org/pypi/romannumeral


This package is a class for working with Roman Numerals.

* Free software: BSD license
* Documentation: https://romannumeral.readthedocs.org.

Features
--------

* Supports basic mathematic operations
* Can cast to string or int
* Can parse from string or int
